# dead-bytecode

This is a backport of [`bytecode`](https://github.com/MatthieuDartiailh/bytecode)
to Python 2. If you are looking for Python 3.4 and 3.5 support, the latest
version of `bytecode` to support these versions is 0.12.0.


## Installation

```bash
pip install dead-bytecode
```

## Documentation

See the documentation of `bytecode` on [RTD](https://bytecode.readthedocs.io/en/latest/).